@@ -197,6 +197,9 @@ class PreseemModel:
                         setattr(cls, reqtype.DESCRIPTOR.name, reqns)
                         op=getattr(svcstub, method.name)
                         setattr(cls, method.name, partial(wrapper, model=self, op=op, delete=method.name=='Delete', reqtype=reqtype))
+                        if method.output_type and not method.output_type.name.endswith('Response'):
+                            if method.output_type.name not in self._types:
+                                self._types[method.output_type.name] = type(method.output_type.name, (BaseModelObject,), {})
                         for nt in reqtype.DESCRIPTOR.nested_types:
                             # Create a nested object class
                             nc = type(nt.name, (BaseModelObject,), {f: None for f in nt.fields_by_name})
